@@ -5,10 +5,10 @@ use UNIVERSAL;
 #			Interface Definition Language (OMG IDL CORBA v3.0)
 #
 
-package CORBA::HTML;
+package CORBA::HTML::html;
 
 use vars qw($VERSION);
-$VERSION = '2.20';
+$VERSION = '2.21';
 
 package CORBA::HTML::htmlVisitor;
 
@@ -77,7 +77,7 @@ sub _format_head {
 	print OUT "<html xmlns='http://www.w3.org/1999/xhtml'>\n";
 	print OUT "\n";
 	print OUT "  <head>\n";
-	print OUT "    <meta name='generator' content='idl2html ",$CORBA::HTML::VERSION," (Perl ",$],")' />\n";
+	print OUT "    <meta name='generator' content='idl2html ",$CORBA::HTML::html::VERSION," (Perl ",$],")' />\n";
 	print OUT "    <meta name='date' content='",$now,"' />\n";
 	print OUT "    <meta http-equiv='Content-Type' content='text/html; charset=ISO-8859-1' />\n";
 	print OUT "    <title>",$title,"</title>\n" if ($title);
@@ -439,7 +439,7 @@ sub visitSpecification {
 
 		print OUT "<HTML>\n";		# no XHTML
 		print OUT "  <HEAD>\n";
-		print OUT "    <meta name=\"generator\" content=\"idl2html ",$CORBA::HTML::VERSION," (Perl ",$],")\">\n";
+		print OUT "    <meta name=\"generator\" content=\"idl2html ",$CORBA::HTML::html::VERSION," (Perl ",$],")\">\n";
 		print OUT "  </HEAD>\n";
 		print OUT "  <BODY>\n";
 		print OUT "    <OBJECT type=\"text/site properties\">\n";
@@ -494,7 +494,7 @@ sub visitSpecification {
 
 		print OUT "<HTML>\n";		# no XHTML
 		print OUT "  <HEAD>\n";
-		print OUT "    <meta name=\"generator\" content=\"idl2html ",$CORBA::HTML::VERSION," (Perl ",$],")\">\n";
+		print OUT "    <meta name=\"generator\" content=\"idl2html ",$CORBA::HTML::html::VERSION," (Perl ",$],")\">\n";
 		print OUT "  </HEAD>\n";
 		print OUT "  <BODY>\n";
 		print OUT "    <UL>\n";
